Weaviate python client
======================
.. image:: https://raw.githubusercontent.com/weaviate/weaviate/19de0956c69b66c5552447e84d016f4fe29d12c9/docs/assets/weaviate-logo.png
    :width: 180
    :align: right
    :alt: Weaviate logo

.. image:: https://github.com/weaviate/weaviate-python-client/actions/workflows/.github/workflows/main.yaml/badge.svg?branch=main
    :target: https://github.com/weaviate/weaviate/actions/workflows/.github/workflows/pull_requests.yaml
    :alt: Build Status

.. image:: https://badge.fury.io/py/weaviate-client.svg
    :target: https://badge.fury.io/py/weaviate-client
    :alt: PyPI version

.. image:: https://readthedocs.org/projects/weaviate-python-client/badge/?version=latest
    :target: https://weaviate-python-client.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

A python native client for easy interaction with a Weaviate instance.

The client is tested for python 3.8 and higher.

Visit the official `Weaviate <https://weaviate.io/>`_ website for more information about the Weaviate and how to use it in production.

Check out our `Command Line Interface (CLI) tool <https://pypi.org/project/weaviate-cli/>`_ for interacting with a Weaviate instance directly from your Terminal.

Articles
--------

Here are some articles on Weaviate:

- `Semantic Search Queries Return More Informed Results <https://hackernoon.com/semantic-search-queries-return-more-informed-results-nr5335nw>`_
- `Getting Started with Weaviate Python Library <https://towardsdatascience.com/getting-started-with-weaviate-python-client-e85d14f19e4f>`_
- `A sub-50ms neural search with DistilBERT and Weaviate <https://towardsdatascience.com/a-sub-50ms-neural-search-with-distilbert-and-weaviate-4857ae390154>`_


Documentation
-------------

- `Documentation <https://weaviate-python-client.readthedocs.io>`_
- More examples can be found at `weaviate.io <https://weaviate.io/developers/weaviate/client-libraries/python>`_.

Support
-------

- Use our `Slack Channel <https://join.slack.com/t/weaviate/shared_invite/zt-goaoifjr-o8FuVz9b1HLzhlUfyfddhw>`_ for support or any other question.
- Use the ``weaviate`` tag on `StackOverflow <https://stackoverflow.com/questions/tagged/weaviate>`_  for questions.
- For bugs and/or problems with the package, submit a GitHub `issue <https://github.com/weaviate/weaviate-python-client/issues>`_.

Contributing
------------
To contribute read `How to Contribute <https://github.com/weaviate/weaviate-python-client/blob/main/CONTRIBUTING.md>`_.
